# image_processing

Description.

The package image_processing is used to:

    Processing:

* Histogram matching
* Strutuctural similarity
* Resize image

Utils:

* Read image
* Save image
* Plot image
* Plot result
* Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/ "Follow de package address")  to install  Image_processing

```
pip install image_processing
```

## Author

@clesiofmatias

## Licence

[MIT](https://choosealicense.com/licenses/mit/ "Go to MIT license")
